Learn R Programming

sophisthse (version 0.7.0)

get_stat_hse_info_vector: Obtain additional information for specific time series

Description

Obtain additional information for specific time series from sophist.hse.ru

Usage

get_stat_hse_info_vector(series.name = "IP_EA_Q", n.vars = 1, info = c("methodology", "source", "comment"), ...)

Arguments

series.name
the names of the time series
n.vars
number of variables
info
type of information (methodology/source/comment)
...
further arguments passed into getURL. One may use them to work with proxy.

Value

character vector with info for each variable

Details

Internal function. Obtain additional information for specific time series from sophist.hse.ru. Either 'methodology', 'source' or 'comment'.

Examples

Run this code
info <- sophisthse:::get_stat_hse_info_vector('IP_EA_Q', 1, 'methodology')

Run the code above in your browser using DataLab