Learn R Programming

sophisthse (version 0.7.0)

series2tables: Get table name from time series name

Description

Get table name from time series name

Usage

series2tables(ts_names)

Arguments

ts_names
character vector of time series or table names

Value

character vector of corresponding table names

Details

On sophist.hse.ru time series are stored in tables. The package download whole tables and not individual time series. When user requests time series we need to know corresponding table name.

Examples

Run this code
series2tables("M2_Y")

Run the code above in your browser using DataLab