Rdocumentation
powered by
Learn R Programming
sophisthse (version 0.7.0)
rus2num: Convert string with a number in Russian tradition in numeric
Description
This function is useful for automatic conversion of strings to numeric
Usage
rus2num(x)
Arguments
x
the string with the number
Value
numeric the number converted from the string
Details
Russian standards prescribes to use comma as a decimal separator. This function removes spaces and converts string to number.
Examples
Run this code
rus2num(
'34 345,34'
)
Run the code above in your browser using
DataLab